@@ -25,7 +25,6 @@ private slots:
     void httpFinished();
     void httpReadyRead();
     void parseWikiText(QString title, QString article);
-  //  void followDownloadProgress(qint64 received, qint64 total);
 
 private:
     QUrl url;
@@ -42,7 +41,7 @@ signals:
     void searchTitlesReceived(QList<QString> titles);
     void articleContentReceived(QString title, QString content);
     void playlistArticleSaved();
-//    void downloadProgress(qint64 received, qint64 total);
+    void downloadProgress(qint64 received, qint64 total);
 
 };
 
